Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <https://keepachangelog.com/en/1.0.0/>`_,
and this project adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_.

[Unreleased]
------------

[0.0.26] - 2020-10-28
---------------------

Added
~~~~~

* First complete state of the package.

[0.0.1] - 2020-10-11
--------------------

Added
~~~~~

* Initial working code.
